An AEA is an intelligent agent whose goal is generating economic value for its owner. It can represent machines, humans, or data. 

There are five general application areas for AEAs:

* **Inhabitants**: agents paired with real world hardware devices such as drones, laptops, heat sensors, etc. An example can be found <a href="../thermometer-skills">here</a>.
* **Interfaces**: facilitation agents which provide the necessary API interfaces for interaction between old (Web 2.0) and new (Web 3.0) economic models.
* **Pure software**: software agents living in the digital space that interact with inhabitant and interface agents and others.
* **Digital data sales agents**: pure software agents that attach to data sources and sell it via the open economic framework. An example can be found <a href="../ml-skills">here</a>.
* **Representative**: an agent which represents an individual's activities on the Fetch.ai network. An example can be found <a href="../tac-skills">here</a>.

## Multi-agent system versus agent-based modelling

The Fetch.ai multi agent system is a real world multi-agent technological system and, although there is some overlap, it is not the same as agent based modelling where the goal is scientific behavioural observation rather than practical economic gain.

Moreover, there is no restriction to *multi*. Single-agent applications are also possible.




<br />
